(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
	typeof define === 'function' && define.amd ? define(['exports'], factory) :
	(global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.UltimateI18n = {}));
})(this, (function (exports) { 'use strict';

	function attr(lang) {
	    return {
	        name: `i18n-${lang}`,
	        selector: `[i18n-${lang}]`
	    };
	}

	const key = 'ultimateI18n';
	function readSelectedLang() {
	    return localStorage[key];
	}
	function writeSelectedLang(lang) {
	    localStorage[key] = lang;
	}

	const isSupported = typeof MutationObserver === 'function';
	const htmlElement = document.getElementsByTagName('html')[0];
	const defaultLanguage = htmlElement.getAttribute('lang') || 'en';
	const defaultAttr = attr(defaultLanguage);
	const lockAttrName = 'i18n-lock';
	let currentLanguage = readSelectedLang() || navigator.language.split('-')[0];
	let currentAttr = attr(currentLanguage);
	let currentLock = '1';
	function updateHtmlLang(lang) {
	    htmlElement.setAttribute('lang', lang);
	}
	function applyDirectly(element, attr) {
	    const langAttr = element.attributes.getNamedItem(attr.name);
	    if (langAttr) {
	        const lock = element.getAttribute(lockAttrName);
	        if (lock === null || lock !== currentLock) {
	            if (lock === null) {
	                element.setAttribute(defaultAttr.name, element.innerText);
	            }
	            element.setAttribute(lockAttrName, currentLock);
	            element.innerText = langAttr.value;
	            return true;
	        }
	    }
	    return false;
	}
	function applyDeeply(element, attr) {
	    applyDirectly(element, attr);
	    const elements = element.querySelectorAll(attr.selector);
	    const count = elements.length;
	    for (let i = 0; i < count; i++) {
	        applyDirectly(elements[i], attr);
	    }
	}
	function callback(mutations) {
	    for (const mutation of mutations) {
	        if (mutation.type === 'childList') {
	            for (let index = 0; index < mutation.addedNodes.length; index++) {
	                const node = mutation.addedNodes[index];
	                if (node.nodeType === Node.ELEMENT_NODE) {
	                    applyDeeply(node, currentAttr);
	                }
	            }
	        }
	    }
	}
	function replace() {
	    const elements = document.querySelectorAll(`[${lockAttrName}], ${currentAttr.selector}`);
	    const count = elements.length;
	    for (let index = 0; index < count; index++) {
	        const element = elements[index];
	        if (!applyDirectly(element, currentAttr)) {
	            applyDirectly(element, defaultAttr);
	        }
	    }
	}
	if (isSupported) {
	    if (defaultLanguage !== currentLanguage) {
	        updateHtmlLang(currentLanguage);
	    }
	    const observer = new MutationObserver(callback);
	    observer.observe(htmlElement, {
	        childList: true,
	        subtree: true
	    });
	}
	function set(lang) {
	    if (!isSupported) {
	        throw new Error('UltimateI18n is not supported');
	    }
	    writeSelectedLang(lang);
	    updateHtmlLang(lang);
	    currentLanguage = lang;
	    currentAttr = attr(lang);
	    currentLock = String(parseInt(currentLock) + 1);
	    replace();
	}
	function get() {
	    return currentLanguage;
	}
	function setup() {
	    replace();
	}

	exports.get = get;
	exports.isSupported = isSupported;
	exports.set = set;
	exports.setup = setup;

	Object.defineProperty(exports, '__esModule', { value: true });

}));
